==> wls-plugin-1.3-sources.jar: com/xebialabs/deployit/plugin/wls/step/StopWlsServerWithWindowsService.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.step;

import com.xebialabs.deployit.Step;
import com.xebialabs.deployit.plugin.wls.ci.WlsServer;

/**
 * Stops a {@link com.xebialabs.deployit.plugin.wls.ci.WlsServer} by invoking a net stop (windows service.
 */
@SuppressWarnings("serial")
public class StopWlsServerWithWindowsService extends WlsWindowsServiceHandler implements Step {

	private static final String STOP_WEBLOGIC_SERVER_SCRIPT_NAME = WlsStepBase.STEP_RESOURCES_PATH + "stop_wls_server_using_services.template";

	public StopWlsServerWithWindowsService(WlsServer server) {
		super(server);
	}

	@Override
	String getTemplatePath() {
		return STOP_WEBLOGIC_SERVER_SCRIPT_NAME;
	}

	@Override
	String getCmdPrefix() {
		return "netStop";
	}

	public String getDescription() {
		return "Stop Weblogic server " + serverName + " using Windows Services on host "+ server.getHost();
	}

}

==> wls-plugin-1.4-sources.jar: com/xebialabs/deployit/plugin/wls/step/StopWlsServerWithWindowsService.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.step;

import com.xebialabs.deployit.Step;
import com.xebialabs.deployit.plugin.wls.ci.WlsServer;
import org.apache.commons.lang.StringUtils;

/**
 * Stops a {@link com.xebialabs.deployit.plugin.wls.ci.WlsServer} by invoking a net stop (windows service.
 */
@SuppressWarnings("serial")
public class StopWlsServerWithWindowsService extends WlsWindowsServiceHandler implements Step {

	private static final String STOP_WEBLOGIC_SERVER_SCRIPT_NAME = WlsStepBase.STEP_RESOURCES_PATH + "stop_wls_server_using_services.template";

	public StopWlsServerWithWindowsService(WlsServer server) {
		super(server);
	}

	@Override
	public String getTemplate() {
		final String command = server.getStopCommand();
		if (!StringUtils.isBlank(command)) {
			return command;
		}
		return getTemplate(STOP_WEBLOGIC_SERVER_SCRIPT_NAME);
	}

	@Override
	public String getCmdPrefix() {
		return "netStop";
	}

	public String getDescription() {
		return "Stop Weblogic server " + serverName + " using Windows Services on host " + server.getHost();
	}

}
